mapping = {
    '!': '1aBcD2E',
    '"': 'FgHiJ3Kl',
    '#': 'M4nOpQr',
    '$': 'S5tUvWx',
    '%': 'YzAbC6D',
    '&': 'EfGhI7Jk',
    "'": 'LmNoPQ8',
    '(': 'R9sTuVW',
    ')': 'XyZaBcD',
    '*': 'EeFgH10I',
    '+': 'JkLmNoP',
    ',': 'QrStUvW',
    '-': 'XyZaBc11',
    '.': 'DgHiJkL',
    '/': 'MmNoPQr',
    '0': 'SsTtUuV',
    '1': 'VvWwXxY',
    '2': 'YyZzAaB',
    '3': 'CkLmNoP',
    '4': 'QrStUvW',
    '5': 'XyZaBcD',
    '6': 'EgHiJkL',
    '7': 'MmNoPQr',
    '8': 'SsTtUuV',
    '9': 'VvWwXxY',
    ':': 'YyZzAaB',
    ';': 'CkLmNoP',
    '<': 'QrStUvW',
    '=': 'XyZaBcD',
    '>': 'EgHiJkL',
    '?': 'MmNoPQr',
    '@': 'SsTtUuV',
    'A': 'VvWwXxY',
    'B': 'YyZzAaB',
    'C': 'CkLmNoP',
    'D': 'QrStUvW',
    'E': 'XyZaBcD',
    'F': 'EgHiJkL',
    'G': 'MmNoPQr',
    'H': 'SsTtUuV',
    'I': 'VvWwXxY',
    'J': 'YyZzAaB',
    'K': 'CkLmNoP',
    'L': 'QrStUvW',
    'M': 'XyZaBcD',
    'N': 'EgHiJkL',
    'O': 'MmNoPQr',
    'P': 'SsTtUuV',
    'Q': 'VvWwXxY',
    'R': 'YyZzAaB',
    'S': 'CkLmNoP',
    'T': 'QrStUvW',
    'U': 'XyZaBcD',
    'V': 'EgHiJkL',
    'W': 'MmNoPQr',
    'X': 'SsTtUuV',
    'Y': 'VvWwXxY',
    'Z': 'YyZzAaB',
    '[': 'CkLmNoP',
    '\\': 'QrStUvW',
    ']': 'XyZaBcD',
    '^': 'EgHiJkL',
    '_': 'MmNoPQr',
    '`': 'SsTtUuV',
    'a': 'VvWwXxY',
    'b': 'YyZzAaB',
    'c': 'CkLmNoP',
    'd': 'QrStUvW',
    'e': 'XyZaBcD',
    'f': 'EgHiJkL',
    'g': 'MmNoPQr',
    'h': 'SsTtUuV',
    'i': 'VvWwXxY',
    'j': 'YyZzAaB',
    'k': 'CkLmNoP',
    'l': 'QrStUvW',
    'm': 'XyZaBcD',
    'n': 'EgHiJkL',
    'o': 'MmNoPQr',
    'p': 'SsTtUuV',
    'q': 'VvWwXxY',
    'r': 'YyZzAaB',
    's': 'CkLmNoP',
    't': 'QrStUvW',
    'u': 'XyZaBcD',
    'v': 'EgHiJkL',
    'w': 'MmNoPQr',
    'x': 'SsTtUuV',
    'y': 'VvWwXxY',
    'z': 'YyZzAaB',
    '{': 'CkLmNoP',
    '|': 'QrStUvW',
    '}': 'XyZaBcD',
    '~': 'EgHiJkL',
    '¡': 'MmNoPQr',
    '¢': 'SsTtUuV',
    '£': 'VvWwXxY',
    '¤': 'YyZzAaB',
    '¥': 'CkLmNoP',
    '¦': 'QrStUvW',
    '§': 'XyZaBcD',
    '¨': 'EgHiJkL',
    '©': 'MmNoPQr',
    'ª': 'SsTtUuV',
    '«': 'VvWwXxY',
    '¬': 'YyZzAaB',
    '­': 'CkLmNoP',
    '®': 'QrStUvW',
    '¯': 'XyZaBcD',
    '°': 'EgHiJkL',
    '±': 'MmNoPQr',
    '²': 'SsTtUuV',
    '³': 'VvWwXxY',
    '´': 'YyZzAaB',
    'µ': 'CkLmNoP',
    '¶': 'QrStUvW',
    '·': 'XyZaBcD',
    '¸': 'EgHiJkL',
    '¹': 'MmNoPQr',
    'º': 'SsTtUuV',
    '»': 'VvWwXxY',
    '¼': 'YyZzAaB',
    '½': 'CkLmNoP',
    '¾': 'QrStUvW',
    '¿': 'XyZaBcD',
    'À': 'EgHiJkL',
    'Á': 'MmNoPQr',
    'Â': 'SsTtUuV',
    'Ã': 'VvWwXxY',
    'Ä': 'YyZzAaB',
    'Å': 'CkLmNoP',
    'Æ': 'QrStUvW',
    'Ç': 'XyZaBcD',
    'È': 'EgHiJkL',
    'É': 'MmNoPQr',
    'Ê': 'SsTtUuV',
    'Ë': 'VvWwXxY',
    'Ì': 'YyZzAaB',
    'Í': 'CkLmNoP',
    'Î': 'QrStUvW',
    'Ï': 'XyZaBcD',
    'Ð': 'EgHiJkL',
    'Ñ': 'MmNoPQr',
    'Ò': 'SsTtUuV',
    'Ó': 'VvWwXxY',
    'Ô': 'YyZzAaB',
    'Õ': 'CkLmNoP',
    'Ö': 'QrStUvW',
    '×': 'XyZaBcD',
    'Ø': 'EgHiJkL',
    'Ù': 'MmNoPQr',
    'Ú': 'SsTtUuV',
    'Û': 'VvWwXxY',
    'Ü': 'YyZzAaB',
    'Ý': 'CkLmNoP',
    'Þ': 'QrStUvW',
    'ß': 'XyZaBcD',
    'à': 'EgHiJkL',
    'á': 'MmNoPQr',
    'â': 'SsTtUuV',
    'ã': 'VvWwXxY',
    'ä': 'YyZzAaB',
    'å': 'CkLmNoP',
    'æ': 'QrStUvW',
    'ç': 'XyZaBcD',
    'è': 'EgHiJkL',
    'é': 'MmNoPQr',
    'ê': 'SsTtUuV',
    'ë': 'VvWwXxY',
    'ì': 'YyZzAaB',
    'í': 'CkLmNoP',
    'î': 'QrStUvW',
    'ï': 'XyZaBcD',
    'ð': 'EgHiJkL',
    'ñ': 'MmNoPQr',
    'ò': 'SsTtUuV',
    'ó': 'VvWwXxY',
    'ô': 'YyZzAaB',
    'õ': 'CkLmNoP',
    'ö': 'QrStUvW',
    '÷': 'XyZaBcD',
    'ø': 'EgHiJkL',
    'ù': 'MmNoPQr',
    'ú': 'SsTtUuV',
    'û': 'VvWwXxY',
    'ü': 'YyZzAaB',
    'ý': 'CkLmNoP',
    'þ': 'QrStUvW',
    'ÿ': 'XyZaBcD',
}
    
reverse_mapping = {
    '1aBcD2E': '!',
    'FgHiJ3Kl': '"',
    'M4nOpQr': '#',
    'S5tUvWx': '$',
    'YzAbC6D': '%',
    'EfGhI7Jk': '&',
    'LmNoPQ8': "'",
    'R9sTuVW': '(',
    'XyZaBcD': ')',
    'EeFgH10I': '*',
    'JkLmNoP': '+',
    'QrStUvW': ',',
    'XyZaBc11': '-',
    'DgHiJkL': '.',
    'MmNoPQr': '/',
    'SsTtUuV': '0',
    'VvWwXxY': '1',
    'YyZzAaB': '2',
    'CkLmNoP': '3',
    'QrStUvW': '4',
    'XyZaBcD': '5',
    'EgHiJkL': '6',
    'MmNoPQr': '7',
    'SsTtUuV': '8',
    'VvWwXxY': '9',
    'YyZzAaB': ':',
    'CkLmNoP': ';',
    'QrStUvW': '<',
    'XyZaBcD': '=',
    'EgHiJkL': '>',
    'MmNoPQr': '?',
    'SsTtUuV': '@',
    'VvWwXxY': 'A',
    'YyZzAaB': 'B',
    'CkLmNoP': 'C',
    'QrStUvW': 'D',
    'XyZaBcD': 'E',
    'EgHiJkL': 'F',
    'MmNoPQr': 'G',
    'SsTtUuV': 'H',
    'VvWwXxY': 'I',
    'YyZzAaB': 'J',
    'CkLmNoP': 'K',
    'QrStUvW': 'L',
    'XyZaBcD': 'M',
    'EgHiJkL': 'N',
    'MmNoPQr': 'O',
    'SsTtUuV': 'P',
    'VvWwXxY': 'Q',
    'YyZzAaB': 'R',
    'CkLmNoP': 'S',
    'QrStUvW': 'T',
    'XyZaBcD': 'U',
    'EgHiJkL': 'V',
    'MmNoPQr': 'W',
    'SsTtUuV': 'X',
    'VvWwXxY': 'Y',
    'YyZzAaB': 'Z',
    'CkLmNoP': '[',
    'QrStUvW': '\\',
    'XyZaBcD': ']',
    'EgHiJkL': '^',
    'DgHiJkL': '_',
    'SsTtUuV': '`',
    'VvWwXxY': 'a',
    'YyZzAaB': 'b',
    'CkLmNoP': 'c',
    'QrStUvW': 'd',
    'XyZaBcD': 'e',
    'EgHiJkL': 'f',
    'MmNoPQr': 'g',
    'SsTtUuV': 'h',
    'VvWwXxY': 'i',
    'YyZzAaB': 'j',
    'CkLmNoP': 'k',
    'QrStUvW': 'l',
    'XyZaBcD': 'm',
    'EgHiJkL': 'n',
    'MmNoPQr': 'o',
    'SsTtUuV': 'p',
    'VvWwXxY': 'q',
    'YyZzAaB': 'r',
    'CkLmNoP': 's',
    'QrStUvW': 't',
    'XyZaBcD': 'u',
    'EgHiJkL': 'v',
    'MmNoPQr': 'w',
    'SsTtUuV': 'x',
    'VvWwXxY': 'y',
    'YyZzAaB': 'z',
    'CkLmNoP': '{',
    'QrStUvW': '|',
    'XyZaBcD': '}',
    'EgHiJkL': '~',
    'MmNoPQr': '¡',
    'SsTtUuV': '¢',
    'VvWwXxY': '£',
    'YyZzAaB': '¤',
    'CkLmNoP': '¥',
    'QrStUvW': '¦',
    'XyZaBcD': '§',
    'EgHiJkL': '¨',
    'MmNoPQr': '©',
    'SsTtUuV': 'ª',
    'VvWwXxY': '«',
    'YyZzAaB': '¬',
    'DgHiJkL': '­',
    'SsTtUuV': '®',
    'XyZaBcD': '¯',
    'EgHiJkL': '°',
    'MmNoPQr': '±',
    'SsTtUuV': '²',
    'VvWwXxY': '³',
    'YyZzAaB': '´',
    'CkLmNoP': 'µ',
    'QrStUvW': '¶',
    'XyZaBcD': '·',
    'EgHiJkL': '¸',
    'MmNoPQr': '¹',
    'SsTtUuV': 'º',
    'VvWwXxY': '»',
    'YyZzAaB': '¼',
    'CkLmNoP': '½',
    'QrStUvW': '¾',
    'XyZaBcD': '¿',
    'EgHiJkL': 'À',
    'MmNoPQr': 'Á',
    'SsTtUuV': 'Â',
    'VvWwXxY': 'Ã',
    'YyZzAaB': 'Ä',
    'CkLmNoP': 'Å',
    'QrStUvW': 'Æ',
    'XyZaBcD': 'Ç',
    'EgHiJkL': 'È',
    'MmNoPQr': 'É',
    'SsTtUuV': 'Ê',
    'VvWwXxY': 'Ë',
    'YyZzAaB': 'Ì',
    'CkLmNoP': 'Í',
    'QrStUvW': 'Î',
    'XyZaBcD': 'Ï',
    'EgHiJkL': 'Ð',
    'MmNoPQr': 'Ñ',
    'SsTtUuV': 'Ò',
    'VvWwXxY': 'Ó',
    'YyZzAaB': 'Ô',
    'CkLmNoP': 'Õ',
    'QrStUvW': 'Ö',
    'XyZaBcD': '×',
    'EgHiJkL': 'Ø',
    'MmNoPQr': 'Ù',
    'SsTtUuV': 'Ú',
    'VvWwXxY': 'Û',
    'YyZzAaB': 'Ü',
    'CkLmNoP': 'Ý',
    'QrStUvW': 'Þ',
    'XyZaBcD': 'ß',
    'EgHiJkL': 'à',
    'MmNoPQr': 'á',
    'SsTtUuV': 'â',
    'VvWwXxY': 'ã',
    'YyZzAaB': 'ä',
    'CkLmNoP': 'å',
    'QrStUvW': 'æ',
    'XyZaBcD': 'ç',
    'EgHiJkL': 'è',
    'MmNoPQr': 'é',
    'SsTtUuV': 'ê',
    'VvWwXxY': 'ë',
    'YyZzAaB': 'ì',
    'CkLmNoP': 'í',
    'QrStUvW': 'î',
    'XyZaBcD': 'ï',
    'EgHiJkL': 'ð',
    'MmNoPQr': 'ñ',
    'SsTtUuV': 'ò',
    'VvWwXxY': 'ó',
    'YyZzAaB': 'ô',
    'CkLmNoP': 'õ',
    'QrStUvW': 'ö',
    'XyZaBcD': '÷',
    'EgHiJkL': 'ø',
    'MmNoPQr': 'ù',
    'SsTtUuV': 'ú',
    'VvWwXxY': 'û',
    'YyZzAaB': 'ü',
    'CkLmNoP': 'ý',
    'QrStUvW': 'þ',
    'XyZaBcD': 'ÿ',
}



def encrypt(mapping, str):
    
    encoded_str = ''.join(mapping.get(char, char) for char in str)
    
    return encoded_str

def decrypt(reverse_mapping, encoded_str):
    decoded_str = ''.join(reverse_mapping.get(encoded_str[i:i+7], encoded_str[i:i+7]) for i in range(0, len(encoded_str), 7))

    return decoded_str
